@@ -36,11 +36,6 @@ class UniUtil:
             pass
         return res
 
-    @staticmethod
-    def uuidd(param: dict = None):
-        """字典uuid"""
-        return UniUtil.uuids(param)
-
     @staticmethod
     def uuids(param: str = None):
         """字典uuid"""
@@ -52,7 +47,7 @@ class UniUtil:
     @staticmethod
     def get_uuid(param: dict = None):
         """基于名字的MD5散列值，同一命名空间的同一名字生成相同的uuid"""
-        UniUtil.uuidd(param)
+        return UniUtil.uuids(param)
 
     @staticmethod
     def time_cost(fn):
